==> hprose-0.3.3-dev%2B3.3.2015.tar.gz: lib/src/io/formatter.dart <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * formatter.dart                                         *
 *                                                        *
 * hprose formatter for Dart.                             *
 *                                                        *
 * LastModified: Mar 3, 2015                              *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/
part of hprose.io;

abstract class Formatter {
  static BytesIO serialize(dynamic value, [bool simple = false]) {
    BytesIO bytes = new BytesIO();
    Writer writer = new Writer(bytes, simple);
    writer.serialize(value);
    return bytes;
  }

  static dynamic unserialize(BytesIO bytes, [bool simple = false]) {
    return new Reader(bytes, simple).unserialize();
  }
}

Uint8List serialize(dynamic value, [bool simple = false]) {
  return Formatter.serialize(value, simple).bytes;
}
dynamic unserialize(Uint8List bytes, [bool simple = false]) {
  return Formatter.unserialize(new BytesIO(bytes), simple);
}

==> hprose-0.5.0-dev%2B2.25.2016.tar.gz: lib/src/io/formatter.dart <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * formatter.dart                                         *
 *                                                        *
 * hprose formatter for Dart.                             *
 *                                                        *
 * LastModified: Feb 14, 2016                             *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/
part of hprose.io;

abstract class Formatter {
  static BytesIO serialize(dynamic value, [bool simple = false]) {
    BytesIO bytes = new BytesIO();
    Writer writer = new Writer(bytes, simple);
    writer.serialize(value);
    return bytes;
  }

  static dynamic unserialize(dynamic bytes, [bool simple = false]) {
    if (bytes is! BytesIO) {
      bytes = new BytesIO(bytes);
    }
    return new Reader(bytes, simple).unserialize();
  }
}

Uint8List serialize(dynamic value, [bool simple = false]) {
  return Formatter.serialize(value, simple).bytes;
}
dynamic unserialize(dynamic bytes, [bool simple = false]) {
  return Formatter.unserialize(bytes, simple);
}
